==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface.md <==
# AmazonVpcElasticNetworkInterface


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')
```



| Illustration | AmazonVpcElasticNetworkInterface | AmazonVpcElasticNetworkInterfaceCard | AmazonVpcElasticNetworkInterfaceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface.png) | ![illustration for AmazonVpcElasticNetworkInterface](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface.Local.png) | ![illustration for AmazonVpcElasticNetworkInterfaceCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterfaceCard.Local.png) | ![illustration for AmazonVpcElasticNetworkInterfaceGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterfaceGroup.Local.png) |




## AmazonVpcElasticNetworkInterface

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterface
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterface('AmazonVpcElasticNetworkInterface', 'Amazon Vpc Elastic Network Interface', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterface
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterface('AmazonVpcElasticNetworkInterface', 'Amazon Vpc Elastic Network Interface', 'an optional tech label')
@enduml
```

## AmazonVpcElasticNetworkInterfaceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceCard('AmazonVpcElasticNetworkInterfaceCard', 'Amazon Vpc Elastic Network Interface Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceCard('AmazonVpcElasticNetworkInterfaceCard', 'Amazon Vpc Elastic Network Interface Card', 'an optional description')
@enduml
```

## AmazonVpcElasticNetworkInterfaceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceGroup('AmazonVpcElasticNetworkInterfaceGroup', 'Amazon Vpc Elastic Network Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceGroup('AmazonVpcElasticNetworkInterfaceGroup', 'Amazon Vpc Elastic Network Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface.md <==
# AmazonVpcElasticNetworkInterface


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')
```



| Illustration | AmazonVpcElasticNetworkInterface | AmazonVpcElasticNetworkInterfaceCard | AmazonVpcElasticNetworkInterfaceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface.png) | ![illustration for AmazonVpcElasticNetworkInterface](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface.Local.png) | ![illustration for AmazonVpcElasticNetworkInterfaceCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterfaceCard.Local.png) | ![illustration for AmazonVpcElasticNetworkInterfaceGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterfaceGroup.Local.png) |




## AmazonVpcElasticNetworkInterface

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterface
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterface('AmazonVpcElasticNetworkInterface', 'Amazon Vpc Elastic Network Interface', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterface
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterface('AmazonVpcElasticNetworkInterface', 'Amazon Vpc Elastic Network Interface', 'an optional tech label')
@enduml
```

## AmazonVpcElasticNetworkInterfaceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceCard('AmazonVpcElasticNetworkInterfaceCard', 'Amazon Vpc Elastic Network Interface Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceCard('AmazonVpcElasticNetworkInterfaceCard', 'Amazon Vpc Elastic Network Interface Card', 'an optional description')
@enduml
```

## AmazonVpcElasticNetworkInterfaceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceGroup('AmazonVpcElasticNetworkInterfaceGroup', 'Amazon Vpc Elastic Network Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcElasticNetworkInterfaceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcElasticNetworkInterface')

' renders the element
AmazonVpcElasticNetworkInterfaceGroup('AmazonVpcElasticNetworkInterfaceGroup', 'Amazon Vpc Elastic Network Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
